import React, { useRef, useLayoutEffect, useEffect } from "react";
function useStatefulRef(initialVal = null) {
  let [cur, setCur] = React.useState(initialVal);
  const { current: ref } = React.useRef({
    current: cur
  });
  Object.defineProperty(ref, "current", {
    get: () => cur,
    set: (value) => {
      if (!Object.is(cur, value)) {
        cur = value;
        setCur(value);
      }
    }
  });
  return ref;
}
let observer;
const callBackMap = /* @__PURE__ */ new WeakMap();
function init() {
  if (observer)
    return;
  observer = new ResizeObserver((entries) => {
    entries.forEach((entry) => {
      const maybeCallBacks = callBackMap.get(entry.target);
      const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
      safeCallBacks.forEach((cb) => cb.current(entry));
    });
  });
}
function useResizeObserver(callback, node) {
  var _a;
  const callbackRef = useRef(callback);
  const nodeRef = useStatefulRef();
  useLayoutEffect(() => {
    callbackRef.current = callback;
  });
  const currentNode = (_a = nodeRef.current) != null ? _a : node;
  useEffect(() => {
    init();
    if (currentNode) {
      const maybeCallBacks = callBackMap.get(currentNode);
      const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
      const newCallbacks = safeCallBacks.concat(callbackRef);
      callBackMap.set(currentNode, newCallbacks);
      observer.observe(currentNode);
    }
    return () => {
      if (currentNode) {
        const maybeCallBacks = callBackMap.get(currentNode);
        const safeCallBacks = maybeCallBacks != null ? maybeCallBacks : [];
        const newCallbacks = safeCallBacks.filter((ref) => ref !== callbackRef);
        callBackMap.set(currentNode, newCallbacks);
        if (newCallbacks.length === 0) {
          observer.unobserve(currentNode);
        }
      }
    };
  }, [currentNode]);
  return nodeRef;
}
const useContainterQuery = (node, width = 1, maxWidth) => {
  if (maxWidth !== void 0 && maxWidth <= width) {
    throw new Error(`The second width value, ${maxWidth}, is not larger than ${width}. Please provide a value greater than first width value`);
  }
  const [matches, setMatch] = React.useState(false);
  useResizeObserver((entry) => {
    var _a, _b;
    const nodeWidth = (_b = (_a = entry.borderBoxSize) == null ? void 0 : _a.inlineSize) != null ? _b : entry.contentRect.width;
    if (nodeWidth > 0) {
      const newMatch = maxWidth === void 0 ? nodeWidth <= width : nodeWidth >= width && nodeWidth <= maxWidth;
      setMatch(newMatch);
    }
  }, node);
  return matches;
};
export { useContainterQuery as default };
